@@ -58,6 +58,8 @@ class Magma(object):
             - Passing the indizes of files to automatically slice the list. maybe even with the syntax sliced_magma = magma[a:b]
             - Readout metadata from files, for example using the taglib or such. 
             - If a dir gets passed, add all files within that dir. Alsa a parameter to ask, if it should be done rekursively. 
+            - If hashing files takes very long (for example seen with clock.tick()), give more output. 
+            - Add more commandline switches (verbose, help, ... - see the babtools_gentoo script)
         
         """
         #: All data inside the Magma list
@@ -95,7 +97,10 @@ class Magma(object):
         
     def create_magma_from_files(self, file_paths): 
         """Create a magma file from given file paths"""
-        from create_simple_magma_list import Magma as SimpleMagma
+        try: 
+            from create_simple_magma_list import Magma as SimpleMagma
+        except: 
+            from magma.create_simple_magma_list import Magma as SimpleMagma
         magma = SimpleMagma(file_paths)
         return magma.data
     
@@ -224,3 +229,5 @@ if __name__ == "__main__":
     elif argv[1] == "magma_from_files": 
         magma = Magma(input_files=argv[3:])
         magma.save(argv[2])
+    else: 
+        print usage()
